<div id="top"></div>
<br />
<div align="center">
  <img width="25%" src="../../icon_testing.svg"></img>

  <h3 align="center">ESTEST</h3>

  <p align="center">
    Quantumatic's testing framework
  </p>
</div>

<!-- TABLE OF CONTENTS -->
<details>
  <summary>Table of Contents</summary>
  <ol>
    <li><a href="#about-the-project">About The Project</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
  </ol>
</details>

<!-- ABOUT THE PROJECT -->

## About The Project

ESTEST - is a simple testing framework made in `Python`. It allows you to test things, you want without thinking of testing implementation. Feel free to contribute to this project 😁 (but only at github.com/hikelang/chike official repo).

> Note: this repo was made by taking some old Quantumatic's February C++ and Python codebase 🙂.

<p align="right"><a href="#top">back to top 👆🏻</a></p>

<!-- LICENSE -->

## License

Distributed under the GPL 3.0 License. See `LICENSE` for more information.

<p align="right"><a href="#top">back to top 👆🏻</a></p>

<!-- CONTACT -->

## Contact

- VK: [👐🏾](https://vk.com/ne_pinguy_pzh)
- Discord: `SnakeEatingItSelf#2004`

<p align="right"><a href="#top">back to top 👆🏻</a></p>
